==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/da.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "gemmer...",
    "saved!" : "gemt!",
    "failed!" : "mislykkedes!",
    "Saved" : "Gemt",
    "There was a problem saving your changes. Click to resume editing." : "Der opstod et problem ved lagringen af dine ændringer. Klik for at genoptage redigeringen.",
    "An error occurred!" : "Der opstod en fejl!",
    "Edit" : "Redigér",
    "Mixed" : "Mixed",
    "Preview" : "Vis eksempel",
    "New text file" : "Ny tekst fil",
    "New text file.txt" : "Ny tekst file.txt",
    "You can not open a folder" : "Du kan ikke åbne en mappe",
    "This file is too big to be opened. Please download the file instead." : "FIlen er for stor til at kunne åbnes direkte. Vær venlig at downloade filen i stedet",
    "Cannot read the file." : "Kan ikke læse filen.",
    "Invalid file path supplied." : "Der blev angivet en ugyldig filsti.",
    "The file is locked." : "Filen er låst",
    "An internal server error occurred." : "Der er opstået en intern serverfejl.",
    "You can not write to a folder" : "Du kan ikke skrive til en mappe",
    "Cannot save file as it has been modified since opening" : "Kan ikke gemme filen, da den er blevet ændret efter den blev åbnet",
    "Insufficient permissions" : "Utilstrækkeligt med rettigheder",
    "File path not supplied" : "Filstien er ikke angivet",
    "File mtime not supplied" : "Filen mtime er ikke anvist",
    "Text editor" : "Tekst editor",
    "Text file" : "Tekstfil"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_texteditor/l10n/da.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "gemmer...",
    "saved!" : "gemt!",
    "failed!" : "mislykkedes!",
    "Saved" : "Gemt",
    "There was a problem saving your changes. Click to resume editing." : "Der opstod et problem ved lagringen af dine ændringer. Klik for at genoptage redigeringen.",
    "An error occurred!" : "Der opstod en fejl!",
    "Edit" : "Redigér",
    "Mixed" : "Mixed",
    "Preview" : "Vis eksempel",
    "New text file" : "Ny tekst fil",
    "New text file.txt" : "Ny tekst file.txt",
    "You can not open a folder" : "Du kan ikke åbne en mappe",
    "This file is too big to be opened. Please download the file instead." : "FIlen er for stor til at kunne åbnes direkte. Vær venlig at downloade filen i stedet",
    "Cannot read the file." : "Kan ikke læse filen.",
    "Invalid file path supplied." : "Der blev angivet en ugyldig filsti.",
    "The file is locked." : "Filen er låst",
    "An internal server error occurred." : "Der er opstået en intern serverfejl.",
    "You can not write to a folder" : "Du kan ikke skrive til en mappe",
    "Cannot save file as it has been modified since opening" : "Kan ikke gemme filen, da den er blevet ændret efter den blev åbnet",
    "Could not write to file." : "Kunne ikke skrive til fil.",
    "Insufficient permissions" : "Utilstrækkeligt med rettigheder",
    "File path not supplied" : "Filstien er ikke angivet",
    "File mtime not supplied" : "Filen mtime er ikke anvist",
    "Share not found" : "Delt fil ikke fundet",
    "You are not authorized to open this share" : "Du har ikke adgang til at åbne denne delte fil",
    "Text editor" : "Tekst editor"
},
"nplurals=2; plural=(n != 1);");
